@@ -246,6 +246,7 @@ class DellApi:
                         region = tag['countryCode']
                         logger.warning('Could not parse country code -> {}', region)
 
+                model = tag['productLineDescription']
                 services = []
                 services_start_dates = []
                 services_end_dates = []
@@ -272,6 +273,7 @@ class DellApi:
                 warranty = self._warranty_type_handler(services)
 
                 data.append({"Service Tag": st,
+                             "Model": model,
                              "Country": region,
                              "Warranty": warranty,
                              "Remain": remains,
@@ -358,7 +360,7 @@ def main():
     |   3456789   |     Sweden    |   Basic    |           Expired            | 2007-11-03 |
     |   1234567   | United States | ProSupport | 4 years, 2 months and 0 days | 2025-07-10 |
     +-------------+---------------+------------+------------------------------+------------+
-    
+
     $ dell_api -fw ~/st_example.txt
     +-------------+---------------+------------+------------------------------+------------+
     | Service Tag |    Country    |  Warranty  |            Remain            |  End Date  |
@@ -367,7 +369,7 @@ def main():
     |   3456789   |     Sweden    |   Basic    |           Expired            | 2007-11-03 |
     |   1234567   | United States | ProSupport | 4 years, 2 months and 0 days | 2025-07-10 |
     +-------------+---------------+------------+------------------------------+------------+
-    
+
     """
 
     parser = argparse.ArgumentParser(description="CLI for fetching data from Dell API",
@@ -400,4 +402,4 @@ def main():
 
 
 if __name__ == '__main__':
-    main()
+    main()
\ No newline at end of file
